from datetime import datetime, timedelta
from dbsynce.lib.core import get_admin_url
from dbsynce.models import DocumentFile
from tickets.models import Ticket, TicketList


def create_ticket_company_activation(user, сompany):
    """
    Создание тикета на активацию партнера.
    
    Список: 2101, METASERVICE-ADMIN: Активация партнеров (NEG_REQUEST)
    Тип: 4, NEG_REQUEST
    """
    # FIXME: Возможно нужно автоматически создавать содержимое поля json
    return Ticket.objects.create(
        title=f"Создание нового Партнера '{сompany.legal_name}'",
        ticket_list=TicketList.objects.get(pk=2101),
        ticket_type=4,
        due_date=datetime.now().date() + timedelta(days=30),
        created_by=user,

        note=f"""
            Пользователь {user} #{user.pk} отправил заявку на становление партнером сервиса:\n
            - Имя: {сompany.legal_name}\n
            - ИНН: {сompany.inn}\n
            - Юридический адрес: {сompany.address}\n
            <a href="{get_admin_url(сompany)}">Полная информация</a>\n
            \n
            Проверьте всю информацию и для активации партнера измените статус заявки на ACCEPTED.
            Это будет означать, что договорные отношения между сервисом и партнером, вступают в силу.
        """
    )

def create_ticket_role_activation_partner_admin(user, сompany):
    """
    Создание тикета на получение роли администратора партнера сервиса.
    
    Список: 2102, METASERVICE-ADMIN: Присвоение роли (ACCESS_REQUEST)
    Тип: 3, ACCESS_REQUEST
    """
    return Ticket.objects.create(
        title=f"Запрос прав на становление Партнером '{сompany.legal_name}'",
        ticket_list=TicketList.objects.get(pk=2102),  # Список кому назначается: METASERVICE-ADMIN
        ticket_type=3,  # ACCESS_REQUEST
        due_date=datetime.now().date() + timedelta(days=30),
        created_by=user,

        # FIXME: Возможно нужно автоматически создавать содержимое поля json
        note=f"""
            Пользователь {user} #{user.pk} отправил заявку на роль администратора партнера сервиса.\n
            \n
            <a href="{get_admin_url(сompany)}">Полная информация о компании-партнере</a>\n
            \n
            После принятия изменений назначается роль и получает право на совершение юридически значимых действий от лица Партнера в соответствии с функционалом Сервиса.
        """
    )


def create_ticket_company_docs_verification(user, company, doc):
    """
    Создание тикета на проверку документов партнера.
    
    Список: 2103, METASERVICE-ADMIN: Проверка документов (ST_REQUEST)
    Тип: 1, ST_REQUEST
    """
    doc_name = doc.get_doc_type_display()
    doc_files = DocumentFile.objects.filter(document=doc)

    note = f"Пользователь {user} #{user.pk} добавил новые файлы документа <a href='{get_admin_url(doc)}'>{doc_name}</a> партнера <a href='{get_admin_url(company)}'>{company.legal_name}</a> требующие проверки:<ul>"
    for file in doc_files:
        note += f"<li><a href='{file.file.url}' target='_blank'>{file}</a></li>"
    note += "</ul>"

    return Ticket.objects.create(
        title=f"Проверка документа '{doc_name}' партнера '{company.legal_name}'",
        ticket_list=TicketList.objects.get(pk=2103),
        ticket_type=1,
        due_date=datetime.now().date() + timedelta(days=30),
        created_by=user,
        note=note
    )
    
def create_ticket_provider_activation(user, provider):
    """
    Создание тикета на активацию Услуги.
    
    Список: 2102, METASERVICE-SUPERVISOR: Активация услуг (ST_REQUEST)
    Тип: 1, ST_REQUEST
    """
    # FIXME: Возможно нужно автоматически создавать содержимое поля json
    
    #TODO вместе с созданием тикета должно отправляться уведомление в группу, но может быть это будет на уровне обработчиков
    
    return Ticket.objects.create(
        title=f"Активация услуги '{provider.service}' для исполнителя '{user}'",
        ticket_list=TicketList.objects.get(pk=2102),
        ticket_type=1,
        due_date=datetime.now().date() + timedelta(days=30),
        created_by=user,
#TODO надо сделать более информативный вывод
        note=f"""
            Пользователь {user} отправил заявку на оказание Услуги {provider.service}.\n

            Проверьте всю информацию о необходимых разрешениях и проверках и для активации возможности оказывать такие услуги измените статус заявки на ACCEPTED.
            Это будет означать, что Исполнитель сможет обрабатывать такие заказы.
        """
    )

def create_ticket_service_activation(user, service_category):
    """
    Создание тикета на активацию Услуги.
    
    Список: 2102, METASERVICE-SUPERVISOR: Активация услуг (ST_REQUEST)
    Тип: 1, ST_REQUEST
    """
    # FIXME: Возможно нужно автоматически создавать содержимое поля json
    
    #TODO вместе с созданием тикета должно отправляться уведомление в группу, но может быть это будет на уровне обработчиков
    
    return Ticket.objects.create(
        title=f"Создание новой услуги '{service.id_metaservice}' - '{service.caption}'",
        ticket_list=TicketList.objects.get(pk=2102),
        ticket_type=1,
        due_date=datetime.now().date() + timedelta(days=30),
        created_by=user,
#TODO надо сделать более информативный вывод
        note=f"""
            Пользователь {user} отправил заявку на добавление и активацию услуги сервиса:\n
            - Категория: {service.service_category_id}\n
            - Ресурс: {service.resource}\n
            - Комиссия партнера: {service.company_comission}\n
            - Тарификация: {service.price_type}\n
            - Стоимость км: {service.price_km}\n
            - Стоимость минуты: {service.price_min}\n            
            - Стоимость за количество: {service.price_amount}\n
            - Описание: {service_category.description}\n
            \n
            Проверьте всю информацию и для активации категории сервиса измените статус заявки на ACCEPTED.
            Это будет означать, что Партнер сможет оказывать услуги на указанных условиях.
        """
    )

def create_ticket_service_category_activation(user, service_category):
    """
    Создание тикета на активацию Категории Сервиса.
    
    Список: 2102, METASERVICE-SUPERVISOR: Активация категорий сервисов (ST_REQUEST)
    Тип: 1, ST_REQUEST
    """
    # FIXME: Возможно нужно автоматически создавать содержимое поля json
    
    #TODO вместе с созданием тикета должно отправляться уведомление в группу, но может быть это будет на уровне обработчиков
    
    return Ticket.objects.create(
        title=f"Создание новой категории сервиса '{service_category.id_metaservice}' - '{service_category.caption}'",
        ticket_list=TicketList.objects.get(pk=2102),
        ticket_type=1,
        due_date=datetime.now().date() + timedelta(days=30),
        created_by=user,

        note=f"""
            Пользователь {user} отправил заявку на добавление и активацию категории сервиса:\n
            - Название: {service_category.caption}\n
            - Договор: {service_category.link_agreement}\n
            - Комиссия Сервиса: {service_category.metaservice_comission}\n
            - Тарификация: {service_category.price_type}\n
            - Описание: {service_category.description}\n
            \n
            Проверьте всю информацию и для активации категории сервиса измените статус заявки на ACCEPTED.
            Это будет означать, что Сервис сможет обрабатывать заказы данной категории.
        """
    )
